## Python CLI tools for `mobilecoind`

### Getting your Public Address

Every 32-byte Master Key defines a unique MobileCoin account. You can share the corresponding public address with other users by sending them the base-58 encoded "Address Code" or the "Address URL" generated by this CLI tool. The "Address URL" can be conveniently embedded as the payload of a QR code.

Note that this command creates a monitor for the provided or generated Master Key that will remain active until removed.

Help:
```

python3 get_public_address.py -h

```

Example:
```

python3 get_public_address.py

    Master Key:       2a4976758b6d8d687ba6aea1e934d8b6511a264e6b979ed74c58534e7b575a5b
    Subaddress Index: 0
    Address Code:     d6vRUHZW4dRQqmzmmoLtdejkgoAS3jicYKryHzgAGmUjAPyqo1LjEugi9tpBVYfWxywhxXncYvkVBboERH87voJAZQeiTnkuPretVnnrSb
    Address URL:

```

### Checking your Balance

Because the MobileCoin ledger is encrypted, you must process every transaction with your Master Key in order to check your balance. This CLI tool creates an account monitor, waits for it to process all blocks in the ledger, and then displays the total unspent balance controlled by the provided Master Key.

Note that this command creates a monitor for the provided Master Key that will remain active until removed.

Help:
```

python3 check_balance.py -h

```

Example:
```

python3 check_balance.py -k=<master key (64 hex characters)>

    Master Key:       <master key (64 hex characters)>
    Subaddress Index: 0
    Address Code:     7BeDc5jpZu72AuNavumc8qo8CRJijtQ7QJXyPo9dpnqULaPhe6GdaDNF7cjxkTrDfTcfMgWVgDzKzbvTTwp32KQ78qpx7bUnPYxAgy92caJ
    Address URL:
    Balance:          998401053000000000 pMOB
                      998.40 kMOB

```

### Sending a Payment

Send a payment with value specified in pMOB (-v or --value) or all available funds (-a or --all).

Help:
```
python3 send_payment.py -h

```

Example:
```

python3 send_payment.py -v 10 --sender=<master key (64 hex characters)> --recipient=7BeDc5jpZu72AuNavumc8qo8CRJijtQ7QJXyPo9dpnqULaPhe6GdaDNF7cjxkTrDfTcfMgWVgDzKzbvTTwp32KQ78qpx7bUnPYxAgy92caJ

transaction status is: UNKNOWN
transaction status is: UNKNOWN
transaction status is: UNKNOWN
transaction status is: VERIFIED


    Sender:           <master key (64 hex characters)>
    Recipient:        7BeDc5jpZu72AuNavumc8qo8CRJijtQ7QJXyPo9dpnqULaPhe6GdaDNF7cjxkTrDfTcfMgWVgDzKzbvTTwp32KQ78qpx7bUnPYxAgy92caJ
    Value:            10 picoMOB
                      0.010 nMOB


    Final Status:     Verified

```


### Cleaning up old monitors

The performance of `mobilecoind` can decrease if there are a large number of active monitors. This tool helps you find and remove monitors that you no longer need but have left running in the background.

Use:
```

python3 cleanup_monitors.py

```

### Running `mobilecoind` Benchmarks

This CLI tool measures the performance of the ledger and monitor background synchronization processes and other `mobilecoind` operations that may vary with the performance of your hardware and network connection.

Use:
```

python3 benchmark.py

```
